darkhistory.low_energy.lowE_photons — DarkHistory documentation

# darkhistory.low_energy.lowE_photons

Functions

`compute_fs`(photspec, x, dE_dVdt_inj, dt[, …]) | Compute f(z) fractions for continuum photons, photoexcitation of HI, and photoionization of HI, HeI, HeII
`getf_continuum`(photspec, norm_fac) |
`getf_excitation`(photspec, norm_fac, dt, xe, …) |
`getf_ion`(photspec, norm_fac, n, method) |
`kappa_DM`(photspec, xe) | Compute kappa_DM of the modified tla.

#### Previous topic

darkhistory.low_energy.lowE_electrons.make_interpolator

#### Next topic

darkhistory.low_energy.lowE_photons.compute_fs

### This Page

Show Source